aboutsummaryrefslogtreecommitdiff
path: root/object.h
diff options
context:
space:
mode:
authorJunio C Hamano <gitster@pobox.com>2025-11-19 10:55:40 -0800
committerJunio C Hamano <gitster@pobox.com>2025-11-19 10:55:42 -0800
commitee270059057ca87fe9d9c50dbb5fa1399ed98cb1 (patch)
tree608fde265c9f400544d4277d9a9668da70fc2a44 /object.h
parent7ccfc262d7850f2eddd860b31b9f69a152687702 (diff)
parent7048e74609fbef2c91bfa3a80e3a9c4fc0ac04c9 (diff)
downloadgit-ee270059057ca87fe9d9c50dbb5fa1399ed98cb1.tar.xz
Merge branch 'ps/ref-peeled-tags-fixes'
Another fix-up to "peeled-tags" topic. * ps/ref-peeled-tags-fixes: object: fix performance regression when peeling tags
Diffstat (limited to 'object.h')
-rw-r--r--object.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/object.h b/object.h
index fd15eecce8..6362130597 100644
--- a/object.h
+++ b/object.h
@@ -290,13 +290,13 @@ enum peel_status {
enum peel_object_flags {
/*
* Always verify the object type, even in the case where the looked-up
* object already has an object type. This can be useful when the
* stored object type may be invalid. One such case is when looking up
* objects via tags, where we blindly trust the object type declared by
* the tag.
*/
- PEEL_OBJECT_VERIFY_OBJECT_TYPE = (1 << 0),
+ PEEL_OBJECT_VERIFY_TAGGED_OBJECT_TYPE = (1 << 0),
};
/*
@@ -290,13 +290,13 @@ enum peel_status {
enum peel_object_flags {
/*
- * Always verify the object type, even in the case where the looked-up
- * object already has an object type. This can be useful when the
- * stored object type may be invalid. One such case is when looking up
- * objects via tags, where we blindly trust the object type declared by
- * the tag.
+ * Always verify the object type of the tagged object, even in the case
+ * where the looked-up object already has an object type. This can be
+ * useful when the tagged object type may be invalid. One such case is
+ * when looking up objects via tags, where we blindly trust the object
+ * type declared by the tag.
*/